@@ -28,3 +28,6 @@ class TooManyPlaceholder(Exception):
 
 class NoSuchImage(Exception):
     """When you try to add an image that doesn't exist"""
+
+class InvalidMetadata(Exception):
+    """When the presentation contains invalid metadata.""" 
