@@ -1,6 +1,7 @@
 from bs4 import BeautifulSoup
 import pytest
 from copy import deepcopy
+from datetime import datetime
 from pptx import Presentation
 from pptx.enum.shapes import MSO_SHAPE_TYPE
 from pptx.shapes.shapetree import (SlideShapes, SlidePlaceholder,
@@ -11,8 +12,9 @@ from newsworthy_slides.validationerror import (PlaceholderContentInvalid,
                                                TooManyPlaceholder,
                                                PlaceholderTypeInvalid,
                                                SlideLayoutInvalid,
+                                               InvalidMetadata,
                                                NoSuchImage)
-from newsworthy_slides.parsers import (add_slide,
+from newsworthy_slides.parsers import (add_slide, add_metadata,
                                        _parse_text_placeholder,
                                        _parse_image_placeholder,
                                        _parse_table_placeholder)
@@ -285,6 +287,20 @@ def test_parse_text_with_a_tags():
     assert(len(p.runs) == 3)
     assert(p.runs[1].hyperlink.address == 'http://www.newsworthy.se')
 
+def test_parse_long_text_with_auto_size():
+    html = """
+    <placeholder type="text" auto-size="text-to-fit-shape">
+        <li>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt.</li>
+    </placeholder>    
+    """
+    prs = Presentation()
+    test_slide = prs.slides.add_slide(prs.slide_layouts[3])
+    shape = test_slide.shapes[0]
+    soup = BeautifulSoup(html, 'xml')
+    text_ph = _parse_text_placeholder(soup, shape)
+    assert text_ph.text_frame.auto_size == 2
+    
+
 
 def test_parse_text_with_multiple_tags():
     html = """
@@ -378,6 +394,24 @@ def test_parse_image_placeholder():
     # TODO: Make assertions
     # p = _parse_image_placeholder(html)
 
+def test_parse_image_to_object_placeholder():
+    prs = Presentation()
+    layout_with_obj_ph = prs.slide_layouts[4]
+
+    test_slide = prs.slides.add_slide(layout_with_obj_ph)
+    obj_ph = test_slide.placeholders[4]
+    assert(obj_ph.placeholder_format.type == 7)
+
+    html = """
+    <placeholder type="image">
+        <img src="https://newsworthy.s3.amazonaws.com/robot-writer/charts/3110061949.png">
+    </placeholder>
+    """
+    soup = BeautifulSoup(html, 'xml')
+    placeholder_obj = _parse_image_placeholder(soup, obj_ph, test_slide)
+
+    assert(isinstance(placeholder_obj, SlidePlaceholder) is True)
+
 
 def test_parse_rotated_image():
     ###
@@ -495,3 +529,23 @@ def test_parse_table_placeholder_with_th():
     assert(table.cell(1,0).text == "Övertorneå")
     assert(table.cell(1,1).text == "1/14")
     assert(table.cell(1,2).text == "1/290")
+
+def test_add_metadata():
+    prs = deepcopy(test_pres)
+    html = """
+    <presentation author="Jens" title="Test presentation" created="2020-10-01" category="">
+    </presentation>
+    """
+    add_metadata(html, prs)
+
+    assert prs.core_properties.author == "Jens"
+    assert prs.core_properties.title == "Test presentation"
+    assert prs.core_properties.created == datetime(2020,10,1)
+    prs.save("test.pptx")
+
+    with pytest.raises(InvalidMetadata):
+        html = """
+        <presentation created="bad date">
+        </presentation>
+        """
+        add_metadata(html, prs)
